birdisle package
================

Submodules
----------

birdisle.aioredis module
------------------------

.. automodule:: birdisle.aioredis
    :members:
    :undoc-members:
    :show-inheritance:

birdisle.redis module
---------------------

.. automodule:: birdisle.redis
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: birdisle
    :members:
    :undoc-members:
    :show-inheritance:
